@@ -2,7 +2,7 @@
 #'
 #' Function returning data frame of LAU2 administrative units for the Czech Republic as \code{sf} polygons. It takes no parameters.
 #'
-#' Due to package size constraints the data are stored externally (and a working internet connection is required to use the package). Downloaded size is 36.3 MB (so use with caution, and patience).
+#' Due to package size constraints the data are stored externally (and a working internet connection is required to use the package). Downloaded size is 13.3 MB (so use with caution, and patience).
 #'
 #' @format \code{sf} data frame with 6.258 rows of 14 variables + geometry
 #'
@@ -24,7 +24,7 @@
 #' }
 #'
 #'
-#' @source \url{https://www.arcdata.cz/produkty/geograficka-data/arccr-500}
+#' @source \url{https://vdp.cuzk.cz/}
 #'
 #' @examples
 #' library(sf)
@@ -37,6 +37,6 @@
 #' @export
 
 obce_polygony <- function() {
-  result <- downloader("ObceP.rds")
+  result <- downloader("ObceP-R.rds")
   result
 }
